#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL

utils::globalVariables(c(
    ".", "ResponseId", "response",
    "attentionflag", "kval", "ed50",
    "Attend-SS", "Attend-LL", "magnitude",
    "question", "measure", "value",
    "subjectid", "questionid",
    "hval", "ep50"))
